@@ -1,8 +1,8 @@
-from __future__ import print_function, unicode_literals, division, absolute_import
+from __future__ import absolute_import, division, print_function, unicode_literals
 
-from pyotp.otp import OTP
-from pyotp import utils
-from future.builtins import str
+from . import utils
+from .otp import OTP
+from .compat import str
 
 class HOTP(OTP):
     def at(self, count):
@@ -37,4 +37,6 @@ class HOTP(OTP):
             name,
             initial_count=initial_count,
             issuer_name=issuer_name,
+            algorithm=self.digest().name,
+            digits=self.digits
         )
